# EfficientFormers

**EfficientFormers** is a library which contains some SOTA efficient transformer architectures. Be note that, effcientformers only index **light-weighted and fast** transformer models. 

Currently supported models:

- [efficientformer - 2022](https://github.com/snap-research/EfficientFormer);


will add:

- [EcoFormer - 2022](https://github.com/ziplab/EcoFormer);


Please star and fork! Contribution are very welcomed.



## Install

```
pip install efficientformers
```


## Usage

```python

from efficientformers.efficientformer import EfficientFormer

model = EfficientFormer()
```